@@ -20,8 +20,13 @@ pub trait Ranged {
     fn range(&self) -> Range<Self::ValueType>;
 
     /// This function provides the on-axis part of its range
+    #[allow(clippy::range_plus_one)]
     fn axis_pixel_range(&self, limit: (i32, i32)) -> Range<i32> {
-        limit.0..limit.1
+        if limit.0 < limit.1 {
+            limit.0..limit.1
+        } else {
+            (limit.1 + 1)..(limit.0 + 1)
+        }
     }
 }
 
@@ -40,6 +45,17 @@ pub struct RangedCoord<X: Ranged, Y: Ranged> {
     back_y: (i32, i32),
 }
 
+impl<X: Ranged + Clone, Y: Ranged + Clone> Clone for RangedCoord<X, Y> {
+    fn clone(&self) -> Self {
+        Self {
+            logic_x: self.logic_x.clone(),
+            logic_y: self.logic_y.clone(),
+            back_x: self.back_x,
+            back_y: self.back_y,
+        }
+    }
+}
+
 impl<X: Ranged, Y: Ranged> RangedCoord<X, Y> {
     /// Create a new ranged value coordinate system
     pub fn new<IntoX: Into<X>, IntoY: Into<Y>>(
@@ -105,6 +121,14 @@ impl<X: Ranged, Y: Ranged> RangedCoord<X, Y> {
     pub fn get_y_axis_pixel_range(&self) -> Range<i32> {
         self.logic_y.axis_pixel_range(self.back_y)
     }
+
+    pub fn x_spec(&self) -> &X {
+        &self.logic_x
+    }
+
+    pub fn y_spec(&self) -> &Y {
+        &self.logic_y
+    }
 }
 
 impl<X: Ranged, Y: Ranged> CoordTranslate for RangedCoord<X, Y> {
@@ -152,18 +176,21 @@ impl<'a, X: Ranged, Y: Ranged> MeshLine<'a, X, Y> {
 pub trait DiscreteRanged
 where
     Self: Ranged,
-    Self::ValueType: Eq,
 {
+    type RangeParameter;
+
+    fn get_range_parameter(&self) -> Self::RangeParameter;
+
     /// Get the smallest value that is larger than the `this` value
-    fn next_value(this: &Self::ValueType) -> Self::ValueType;
+    fn next_value(this: &Self::ValueType, param: &Self::RangeParameter) -> Self::ValueType;
 
     /// Get the largest value that is smaller than `this` value
-    fn previous_value(this: &Self::ValueType) -> Self::ValueType;
+    fn previous_value(this: &Self::ValueType, param: &Self::RangeParameter) -> Self::ValueType;
 }
 
 /// The trait for the type that can be converted into a ranged coordinate axis
 pub trait AsRangedCoord: Sized {
-    type CoordDescType: Ranged + From<Self>;
+    type CoordDescType: Ranged<ValueType = Self::Value> + From<Self>;
     type Value;
 }
 
@@ -176,15 +203,21 @@ where
     type Value = T::ValueType;
 }
 
+/// The axis decorator that makes key-point in the center of the value range
+/// This is useful when we draw a histogram, since we want the axis value label
+/// to be shown in the middle of the range rather than exactly the location where
+/// the value mapped to.
 pub struct CentricDiscreteRange<D: DiscreteRanged>(D)
 where
     <D as Ranged>::ValueType: Eq;
 
+/// The trait for types that can decorated by `CentricDiscreteRange` decorator
 pub trait IntoCentric: AsRangedCoord
 where
     Self::CoordDescType: DiscreteRanged,
     <Self::CoordDescType as Ranged>::ValueType: Eq,
 {
+    /// Convert current ranged value into a centric ranged value
     fn into_centric(self) -> CentricDiscreteRange<Self::CoordDescType> {
         CentricDiscreteRange(self.into())
     }
@@ -197,6 +230,15 @@ where
 {
 }
 
+impl<D: DiscreteRanged + Clone> Clone for CentricDiscreteRange<D>
+where
+    <D as Ranged>::ValueType: Eq,
+{
+    fn clone(&self) -> Self {
+        Self(self.0.clone())
+    }
+}
+
 impl<D: DiscreteRanged> Ranged for CentricDiscreteRange<D>
 where
     <D as Ranged>::ValueType: Eq,
@@ -204,7 +246,7 @@ where
     type ValueType = <D as Ranged>::ValueType;
 
     fn map(&self, value: &Self::ValueType, limit: (i32, i32)) -> i32 {
-        let prev = <D as DiscreteRanged>::previous_value(&value);
+        let prev = <D as DiscreteRanged>::previous_value(&value, &self.0.get_range_parameter());
         (self.0.map(&prev, limit) + self.0.map(value, limit)) / 2
     }
 
@@ -221,12 +263,16 @@ impl<D: DiscreteRanged> DiscreteRanged for CentricDiscreteRange<D>
 where
     <D as Ranged>::ValueType: Eq,
 {
-    fn next_value(this: &Self::ValueType) -> Self::ValueType {
-        <D as DiscreteRanged>::next_value(this)
+    type RangeParameter = <D as DiscreteRanged>::RangeParameter;
+    fn get_range_parameter(&self) -> Self::RangeParameter {
+        self.0.get_range_parameter()
+    }
+    fn next_value(this: &Self::ValueType, param: &Self::RangeParameter) -> Self::ValueType {
+        <D as DiscreteRanged>::next_value(this, param)
     }
 
-    fn previous_value(this: &Self::ValueType) -> Self::ValueType {
-        <D as DiscreteRanged>::previous_value(this)
+    fn previous_value(this: &Self::ValueType, param: &Self::RangeParameter) -> Self::ValueType {
+        <D as DiscreteRanged>::previous_value(this, param)
     }
 }
 
@@ -238,9 +284,17 @@ where
     type Value = <Self as Ranged>::ValueType;
 }
 
+/// This axis decorator will make the axis partially display on the axis.
+/// At some time, we want the axis only covers some part of the value.
+/// This decorator will have an additional display range defined.
 pub struct PartialAxis<R: Ranged>(R, Range<R::ValueType>);
 
+/// The trait for the types that can be converted into a partial axis
 pub trait IntoPartialAxis: AsRangedCoord {
+    /// Make the partial axis
+    ///
+    /// - `axis_range`: The range of the axis to be displayed
+    /// - **returns**: The converted range specification
     fn partial_axis(
         self,
         axis_range: Range<<Self::CoordDescType as Ranged>::ValueType>,
@@ -251,6 +305,15 @@ pub trait IntoPartialAxis: AsRangedCoord {
 
 impl<R: AsRangedCoord> IntoPartialAxis for R {}
 
+impl<R: Ranged + Clone> Clone for PartialAxis<R>
+where
+    <R as Ranged>::ValueType: Clone,
+{
+    fn clone(&self) -> Self {
+        PartialAxis(self.0.clone(), self.1.clone())
+    }
+}
+
 impl<R: Ranged> Ranged for PartialAxis<R>
 where
     R::ValueType: Clone,
@@ -282,12 +345,16 @@ where
     R: Ranged,
     <R as Ranged>::ValueType: Eq + Clone,
 {
-    fn next_value(this: &Self::ValueType) -> Self::ValueType {
-        <R as DiscreteRanged>::next_value(this)
+    type RangeParameter = <R as DiscreteRanged>::RangeParameter;
+    fn get_range_parameter(&self) -> Self::RangeParameter {
+        self.0.get_range_parameter()
+    }
+    fn next_value(this: &Self::ValueType, param: &Self::RangeParameter) -> Self::ValueType {
+        <R as DiscreteRanged>::next_value(this, param)
     }
 
-    fn previous_value(this: &Self::ValueType) -> Self::ValueType {
-        <R as DiscreteRanged>::previous_value(this)
+    fn previous_value(this: &Self::ValueType, param: &Self::RangeParameter) -> Self::ValueType {
+        <R as DiscreteRanged>::previous_value(this, param)
     }
 }
 
@@ -299,7 +366,13 @@ where
     type Value = <Self as Ranged>::ValueType;
 }
 
-#[cfg(feature = "make_partial_axis")]
+/// Make a partial axis based on the percentage of visible portion.
+/// We can use `into_partial_axis` to create a partial axis range specification.
+/// But sometimes, we want to directly specify the percentage visible to the user.
+///
+/// - `axis_range`: The range specification
+/// - `part`: The visible part of the axis. Each value is from [0.0, 1.0]
+/// - **returns**: The partial axis created from the input, or `None` when not possible
 pub fn make_partial_axis<T>(
     axis_range: Range<T>,
     part: Range<f64>,
