@@ -1,22 +1,22 @@
 use super::*;
 use super::{Drawable, PointCollection};
 use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
-use crate::style::ShapeStyle;
+use crate::style::{ShapeStyle, SizeDesc};
 
 /// The element that used to describe a point
-pub trait PointElement<Coord> {
-    fn make_point(pos: Coord, size: u32, style: ShapeStyle) -> Self;
+pub trait PointElement<Coord, Size: SizeDesc> {
+    fn make_point(pos: Coord, size: Size, style: ShapeStyle) -> Self;
 }
 
 /// Describe a cross
-pub struct Cross<Coord> {
+pub struct Cross<Coord, Size: SizeDesc> {
     center: Coord,
-    size: u32,
+    size: Size,
     style: ShapeStyle,
 }
 
-impl<Coord> Cross<Coord> {
-    pub fn new<T: Into<ShapeStyle>>(coord: Coord, size: u32, style: T) -> Self {
+impl<Coord, Size: SizeDesc> Cross<Coord, Size> {
+    pub fn new<T: Into<ShapeStyle>>(coord: Coord, size: Size, style: T) -> Self {
         Self {
             center: coord,
             size,
@@ -25,7 +25,7 @@ impl<Coord> Cross<Coord> {
     }
 }
 
-impl<'a, Coord: 'a> PointCollection<'a, Coord> for &'a Cross<Coord> {
+impl<'a, Coord: 'a, Size: SizeDesc> PointCollection<'a, Coord> for &'a Cross<Coord, Size> {
     type Borrow = &'a Coord;
     type IntoIter = std::iter::Once<&'a Coord>;
     fn point_iter(self) -> std::iter::Once<&'a Coord> {
@@ -33,14 +33,15 @@ impl<'a, Coord: 'a> PointCollection<'a, Coord> for &'a Cross<Coord> {
     }
 }
 
-impl<Coord, DB: DrawingBackend> Drawable<DB> for Cross<Coord> {
+impl<Coord, DB: DrawingBackend, Size: SizeDesc> Drawable<DB> for Cross<Coord, Size> {
     fn draw<I: Iterator<Item = BackendCoord>>(
         &self,
         mut points: I,
         backend: &mut DB,
+        ps: (u32, u32),
     ) -> Result<(), DrawingErrorKind<DB::ErrorType>> {
         if let Some((x, y)) = points.next() {
-            let size = self.size as i32;
+            let size = self.size.in_pixels(&ps);
             let (x0, y0) = (x - size, y - size);
             let (x1, y1) = (x + size, y + size);
             backend.draw_line((x0, y0), (x1, y1), &self.style.color)?;
@@ -51,14 +52,14 @@ impl<Coord, DB: DrawingBackend> Drawable<DB> for Cross<Coord> {
 }
 
 /// Describe a triangle marker
-pub struct TriangleMarker<Coord> {
+pub struct TriangleMarker<Coord, Size: SizeDesc> {
     center: Coord,
-    size: u32,
+    size: Size,
     style: ShapeStyle,
 }
 
-impl<Coord> TriangleMarker<Coord> {
-    pub fn new<T: Into<ShapeStyle>>(coord: Coord, size: u32, style: T) -> Self {
+impl<Coord, Size: SizeDesc> TriangleMarker<Coord, Size> {
+    pub fn new<T: Into<ShapeStyle>>(coord: Coord, size: Size, style: T) -> Self {
         Self {
             center: coord,
             size,
@@ -67,7 +68,7 @@ impl<Coord> TriangleMarker<Coord> {
     }
 }
 
-impl<'a, Coord: 'a> PointCollection<'a, Coord> for &'a TriangleMarker<Coord> {
+impl<'a, Coord: 'a, Size: SizeDesc> PointCollection<'a, Coord> for &'a TriangleMarker<Coord, Size> {
     type Borrow = &'a Coord;
     type IntoIter = std::iter::Once<&'a Coord>;
     fn point_iter(self) -> std::iter::Once<&'a Coord> {
@@ -75,20 +76,22 @@ impl<'a, Coord: 'a> PointCollection<'a, Coord> for &'a TriangleMarker<Coord> {
     }
 }
 
-impl<Coord, DB: DrawingBackend> Drawable<DB> for TriangleMarker<Coord> {
+impl<Coord, DB: DrawingBackend, Size: SizeDesc> Drawable<DB> for TriangleMarker<Coord, Size> {
     fn draw<I: Iterator<Item = BackendCoord>>(
         &self,
         mut points: I,
         backend: &mut DB,
+        ps: (u32, u32),
     ) -> Result<(), DrawingErrorKind<DB::ErrorType>> {
         if let Some((x, y)) = points.next() {
+            let size = self.size.in_pixels(&ps);
             let points = [-90, -210, -330]
                 .iter()
                 .map(|deg| f64::from(*deg) * std::f64::consts::PI / 180.0)
                 .map(|rad| {
                     (
-                        (rad.cos() * f64::from(self.size) + f64::from(x)).ceil() as i32,
-                        (rad.sin() * f64::from(self.size) + f64::from(y)).ceil() as i32,
+                        (rad.cos() * f64::from(size) + f64::from(x)).ceil() as i32,
+                        (rad.sin() * f64::from(size) + f64::from(y)).ceil() as i32,
                     )
                 });
             backend.fill_polygon(points, &self.style.color)?;
@@ -97,26 +100,26 @@ impl<Coord, DB: DrawingBackend> Drawable<DB> for TriangleMarker<Coord> {
     }
 }
 
-impl<Coord> PointElement<Coord> for Cross<Coord> {
-    fn make_point(pos: Coord, size: u32, style: ShapeStyle) -> Self {
+impl<Coord, Size: SizeDesc> PointElement<Coord, Size> for Cross<Coord, Size> {
+    fn make_point(pos: Coord, size: Size, style: ShapeStyle) -> Self {
         Self::new(pos, size, style)
     }
 }
 
-impl<Coord> PointElement<Coord> for TriangleMarker<Coord> {
-    fn make_point(pos: Coord, size: u32, style: ShapeStyle) -> Self {
+impl<Coord, Size: SizeDesc> PointElement<Coord, Size> for TriangleMarker<Coord, Size> {
+    fn make_point(pos: Coord, size: Size, style: ShapeStyle) -> Self {
         Self::new(pos, size, style)
     }
 }
 
-impl<Coord> PointElement<Coord> for Circle<Coord> {
-    fn make_point(pos: Coord, size: u32, style: ShapeStyle) -> Self {
+impl<Coord, Size: SizeDesc> PointElement<Coord, Size> for Circle<Coord, Size> {
+    fn make_point(pos: Coord, size: Size, style: ShapeStyle) -> Self {
         Self::new(pos, size, style)
     }
 }
 
-impl<Coord> PointElement<Coord> for Pixel<Coord> {
-    fn make_point(pos: Coord, _: u32, style: ShapeStyle) -> Self {
+impl<Coord, Size: SizeDesc> PointElement<Coord, Size> for Pixel<Coord> {
+    fn make_point(pos: Coord, _: Size, style: ShapeStyle) -> Self {
         Self::new(pos, style)
     }
 }
