@@ -15,7 +15,7 @@
     <img style="display: inline! important" src="https://travis-ci.org/38/plotters.svg?branch=master"></img>
 </a>
 <a href="https://codecov.io/gh/38/plotters">
-  <img src="https://codecov.io/gh/38/plotters/branch/master/graph/badge.svg" />
+    <img style="display: inline! important" src="https://codecov.io/gh/38/plotters/branch/master/graph/badge.svg" />
 </a>
 
 Plotters is drawing library designed for rendering figures, plots, and charts, in pure rust. Plotters supports various types of back-ends,
@@ -101,7 +101,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
         <img src="https://plotters-rs.github.io/plotters-doc-data/plotters-piston.gif" class="galleryItem"></img>
     </a>
     <div class="galleryText">
-        Realtime Rendering
+        Real-time Rendering
         <a href="https://github.com/38/plotters/tree/master/examples/piston-demo">[code]</a>
     </div>
 </div>
@@ -131,7 +131,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
         <img src="https://plotters-rs.github.io/plotters-doc-data/matshow.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
-        The matplotlib Matshow Example
+        The Matplotlib Matshow Example
         <a href="https://github.com/38/plotters/blob/master/examples/matshow.rs">[code]</a>
     </div>
 </div>
@@ -151,7 +151,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
         <img src="https://plotters-rs.github.io/plotters-doc-data/normal-dist2.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
-        The 1D Gussian Distribution
+        The 1D Gaussian Distribution
         <a href="https://github.com/38/plotters/blob/master/examples/nomal-dist2.rs">[code]</a>
     </div>
 </div>
@@ -161,7 +161,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
         <img src="https://plotters-rs.github.io/plotters-doc-data/errorbar.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
-        The 1D Gussian Distribution
+        The 1D Gaussian Distribution
         <a href="https://github.com/38/plotters/blob/master/examples/errorbar.rs">[code]</a>
     </div>
 </div>
@@ -228,6 +228,16 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
     </div>
 </div>
 
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/boxplot.svg">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/boxplot.svg" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Drawing bitmap on chart
+        <a href="https://github.com/38/plotters/blob/master/examples/boxplot.rs">[code]</a>
+    </div>
+</div>
+
 
 ## Table of Contents
   * [Gallery](#gallery)
@@ -254,7 +264,7 @@ including bitmap, vector graph, piston window, GTK/Cairo and WebAssembly.
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [dependencies]
-plotters = "^0.2.11"
+plotters = "^0.2.12"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -279,7 +289,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
             &RED,
         ))?
         .label("y = x^2")
-        .legend(|(x, y)| Path::new(vec![(x, y), (x + 20, y)], &RED));
+        .legend(|(x, y)| PathElement::new(vec![(x, y), (x + 20, y)], &RED));
 
     chart
         .configure_series_labels()
@@ -322,7 +332,7 @@ let figure = evcxr_figure((640, 480), |root| {
         &RED,
     )).unwrap()
         .label("y = x^2")
-        .legend(|(x,y)| Path::new(vec![(x,y), (x + 20,y)], &RED));
+        .legend(|(x,y)| PathElement::new(vec![(x,y), (x + 20,y)], &RED));
 
     chart.configure_series_labels()
         .background_style(&WHITE.mix(0.8))
@@ -590,18 +600,54 @@ This behavior can also be turned off by setting `default_features = false`.
 
 ### List of Features
 
-This is the full list of features that is defined by `Plotters` crate. Use `default_features = false` to disable those default enabled features, and then you should be able to cherry-pick what features you want to include into `Plotters` crate.
+This is the full list of features that is defined by `Plotters` crate.
+Use `default_features = false` to disable those default enabled features,
+and then you should be able to cherry-pick what features you want to include into `Plotters` crate.
+By doing so, you can minimize the number of dependencies down to only `itertools` and compile time is less than 6s.
+
+The following list is a complete list of features that can be opt in and out.
+
+- Drawing backends related features
 
 | Name    |  Description | Additional Dependency |Default?|
 |---------|--------------|--------|------------|
-| bitmap  | Enable `BitMapBackend` Support| image | Yes |
-| svg     | Enable `SVGBackend` Support | svg | Yes |
-| datetime| Enable Date and Time Coordinate Support| chrono | Yes |
+| image\_encoder  | Allow `BitMapBackend` save the result to bitmap files | image, rusttype, font-kit | Yes |
+| svg     | Enable `SVGBackend` Support | None | Yes |
 | gif\_backend| Opt-in GIF animation Rendering support for `BitMapBackend`, implies `bitmap` enabled | gif | Yes |
-| piston | Enable `PistonWindowBackend` | piston\_window | No |
-| palette\_ext | Use crate `palette` for color expression| palette | Yes |
-| evcxr | Enable Evcxr support, which allows use `Plotters` in Jupyter Note Book | None | No |
-| make\_partial\_axis | Support for API `make_partial_axis`, which allows configuring partial axis from visible portion. | num-trait| Yes |
+| piston | Enable `PistonWindowBackend` | piston\_window, rusttype, font-kit | No |
+| cairo | Enable `CairoBackend` | cairo-rs, rusttype, font-kit | No |
+
+- Font manipulation features
+
+| Name    |  Description | Additional Dependency |Default?|
+|---------|--------------|--------|------------|
+| ttf | Allows TrueType font support | rusttype, font-kit | Yes |
+
+- Coordinate features
+
+| Name    |  Description | Additional Dependency |Default?|
+|---------|--------------|--------|------------|
+| datetime | Eanble the date and time coordinate support | chrono | Yes |
+
+- Element, series and util functions
+
+| Name    |  Description | Additional Dependency |Default?|
+|---------|--------------|--------|------------|
+| errorbar | The errorbar element support | None | Yes |
+| candlestick | The candlestick element support | None | Yes |
+| boxplot | The boxplot element support | None | Yes |
+| area\_series | The area series support | None | Yes |
+| line\_series | The line series support | None | Yes |
+| histogram | The histogram series support | None | Yes |
+| point\_series| The point series support | None | Yes |
+
+- Misc
+
+| Name    |  Description | Additional Dependency |Default?|
+|---------|--------------|--------|------------|
+| deprecated\_items | This feature allows use of deprecated items which is going to be removed in the future | None | Yes |
+| debug | Enable the code used for debugging | None | No |
+
 
 ## FAQ List
 
@@ -659,19 +705,24 @@ pub use palette;
 pub mod prelude {
     pub use crate::chart::{ChartBuilder, ChartContext, LabelAreaPosition, SeriesLabelPosition};
     pub use crate::coord::{
-        CoordTranslate, IntoCentric, IntoPartialAxis, LogCoord, LogRange, LogScalable, Ranged,
-        RangedCoord, RangedCoordf32, RangedCoordf64, RangedCoordi32, RangedCoordi64,
-        RangedCoordu32, RangedCoordu64,
+        Category, CoordTranslate, GroupBy, IntoCentric, IntoPartialAxis, LogCoord, LogRange,
+        LogScalable, Ranged, RangedCoord, RangedCoordf32, RangedCoordf64, RangedCoordi32,
+        RangedCoordi64, RangedCoordu32, RangedCoordu64, ToGroupByRange,
     };
 
     #[cfg(feature = "chrono")]
-    pub use crate::coord::{RangedDate, RangedDateTime, RangedDuration};
-
-    #[cfg(feature = "make_partial_axis")]
-    pub use crate::coord::make_partial_axis;
+    pub use crate::coord::{make_partial_axis, RangedDate, RangedDateTime, RangedDuration};
 
     pub use crate::drawing::*;
-    pub use crate::series::{AreaSeries, Histogram, LineSeries, PointSeries};
+    #[cfg(feature = "area_series")]
+    pub use crate::series::AreaSeries;
+    #[cfg(feature = "histogram")]
+    pub use crate::series::Histogram;
+    #[cfg(feature = "line_series")]
+    pub use crate::series::LineSeries;
+    #[cfg(feature = "point_series")]
+    pub use crate::series::PointSeries;
+
     pub use crate::style::{
         AsRelative, Color, FontDesc, FontFamily, FontStyle, FontTransform, HSLColor, IntoFont,
         Palette, Palette100, Palette99, Palette9999, PaletteColor, RGBColor, ShapeStyle,
@@ -680,13 +731,27 @@ pub mod prelude {
     pub use crate::style::{BLACK, BLUE, CYAN, GREEN, MAGENTA, RED, TRANSPARENT, WHITE, YELLOW};
 
     pub use crate::element::{
-        CandleStick, Circle, Cross, DynElement, EmptyElement, ErrorBar, IntoDynElement,
-        MultiLineText, Path, Pixel, Polygon, Rectangle, Text, TriangleMarker,
+        Circle, Cross, DynElement, EmptyElement, IntoDynElement, MultiLineText, PathElement, Pixel,
+        Polygon, Rectangle, Text, TriangleMarker,
     };
 
-    #[cfg(all(not(target_arch = "wasm32"), feature = "image"))]
+    #[cfg(feature = "boxplot")]
+    pub use crate::element::Boxplot;
+    #[cfg(feature = "candlestick")]
+    pub use crate::element::CandleStick;
+    #[cfg(feature = "errorbar")]
+    pub use crate::element::ErrorBar;
+
+    #[cfg(feature = "bitmap")]
     pub use crate::element::BitMapElement;
 
+    pub use crate::data::Quartiles;
+
+    // TODO: This should be deprecated and completely removed
+    #[cfg(feature = "deprecated_items")]
+    #[allow(deprecated)]
+    pub use crate::element::Path;
+
     #[allow(type_alias_bounds)]
     /// The type used to returns a drawing operation that can be failed
     /// - `T`: The return type
